# Angle/Q Tool

Angle/Q Tool shows pixel coordinates in q-space or theta-angles

- Geometry: detector geometry parameters. They can be pass in both ways via LavueController tango server
- theta angles or q-space selects the radial transformation
- pixel/polar-th/polar-q: selects Cartesian or polar plot
- Range: select range and scale of polar plots

The radial center can be selected on Cartesian 2D-plot with a mouse double-click.